elephant.asset.asset.synchronous\_events\_intersection
======================================================

.. currentmodule:: elephant.asset.asset

.. autofunction:: synchronous_events_intersection